diff --git a/PKG-INFO b/PKG-INFO
index 428e3e4b6112cf4af6313035209014f0edd20489..3d524a4db83b3b22188cf0ea9e73d33bcd4f50bc 100644
--- a/PKG-INFO
+++ b/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: swh.deposit
-Version: 0.0.21
+Version: 0.0.22
 Summary: Software Heritage Deposit Server
 Home-page: https://forge.softwareheritage.org/source/swh-deposit/
 Author: Software Heritage developers
diff --git a/docs/Makefile b/docs/Makefile
index 1c40038b8d0f5258bf44cac1a674c574b507967c..e23d856d6594b48a0fb3ac30b6a6707767b9872b 100644
--- a/docs/Makefile
+++ b/docs/Makefile
@@ -1,6 +1,6 @@
 include ../../swh-docs/Makefile.sphinx
 
-html: copy_md
+sphinx/html: copy_md
 
 copy_md:
 	cp ../README-getting-started.md getting-started.md
@@ -8,3 +8,6 @@ copy_md:
 	cp ../README-injection.md spec-injection.md
 	cp ../README-dev.md dev-info.md
 	cp ../README-sys.md sys-info.md
+
+clean:
+	rm -f *.md
diff --git a/swh.deposit.egg-info/PKG-INFO b/swh.deposit.egg-info/PKG-INFO
index 428e3e4b6112cf4af6313035209014f0edd20489..3d524a4db83b3b22188cf0ea9e73d33bcd4f50bc 100644
--- a/swh.deposit.egg-info/PKG-INFO
+++ b/swh.deposit.egg-info/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: swh.deposit
-Version: 0.0.21
+Version: 0.0.22
 Summary: Software Heritage Deposit Server
 Home-page: https://forge.softwareheritage.org/source/swh-deposit/
 Author: Software Heritage developers
diff --git a/swh/deposit/api/common.py b/swh/deposit/api/common.py
index 1b16dcfb792d25677b07c883f9824239c35e1660..c2113bb8ee53f601bad6c7fff9e2801528ac366f 100644
--- a/swh/deposit/api/common.py
+++ b/swh/deposit/api/common.py
@@ -17,7 +17,9 @@ from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticated, AllowAny
 
 from ..config import SWHDefaultConfig, EDIT_SE_IRI, EM_IRI, CONT_FILE_IRI
-from ..config import ARCHIVE_KEY, METADATA_KEY
+from ..config import ARCHIVE_KEY, METADATA_KEY, STATE_IRI
+from ..config import DEPOSIT_STATUS_READY
+
 from ..models import Deposit, DepositRequest, DepositCollection
 from ..models import DepositRequestType, DepositClient
 from ..parsers import parse_xml
@@ -142,7 +144,7 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
         """
         if in_progress is False:
             complete_date = timezone.now()
-            status_type = 'ready'
+            status_type = DEPOSIT_STATUS_READY
         else:
             complete_date = None
             status_type = 'partial'
@@ -385,6 +387,7 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
         return {
             'deposit_id': deposit.id,
             'deposit_date': deposit.reception_date,
+            'status': deposit.status,
             'archive': filehandler.name,
         }
 
@@ -483,6 +486,7 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
             'deposit_id': deposit.id,
             'deposit_date': deposit.reception_date,
             'archive': filehandler.name,
+            'status': deposit.status,
         }
 
     def _atom_entry(self, req, headers, collection_name,
@@ -543,6 +547,7 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
             'deposit_id': deposit.id,
             'deposit_date': deposit.reception_date,
             'archive': None,
+            'status': deposit.status,
         }
 
     def _empty_post(self, req, headers, collection_name, deposit_id):
@@ -562,19 +567,21 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
         """
         deposit = Deposit.objects.get(pk=deposit_id)
         deposit.complete_date = timezone.now()
-        deposit.status = 'ready'
+        deposit.status = DEPOSIT_STATUS_READY
         deposit.save()
 
         return {
             'deposit_id': deposit_id,
             'deposit_date': deposit.complete_date,
+            'status': deposit.status,
             'archive': None,
         }
 
-    def _make_iris(self, collection_name, deposit_id):
+    def _make_iris(self, req, collection_name, deposit_id):
         """Define the IRI endpoints
 
         Args:
+            req (Request): The initial request
             collection_name (str): client/collection's name
             deposit_id (id): Deposit identifier
 
@@ -582,16 +589,10 @@ class SWHBaseDeposit(SWHDefaultConfig, SWHAPIView, metaclass=ABCMeta):
             Dictionary of keys with the iris' urls.
 
         """
+        args = [collection_name, deposit_id]
         return {
-            EM_IRI: reverse(
-                EM_IRI,
-                args=[collection_name, deposit_id]),
-            EDIT_SE_IRI: reverse(
-                EDIT_SE_IRI,
-                args=[collection_name, deposit_id]),
-            CONT_FILE_IRI: reverse(
-                CONT_FILE_IRI,
-                args=[collection_name, deposit_id]),
+            iri: req.build_absolute_uri(reverse(iri, args=args))
+            for iri in [EM_IRI, EDIT_SE_IRI, CONT_FILE_IRI, STATE_IRI]
         }
 
     def additional_checks(self, req, headers, collection_name,
@@ -724,7 +725,6 @@ class SWHPostDepositAPI(SWHBaseDeposit, metaclass=ABCMeta):
             400 if the deposit does not belong to the collection
             404 if the deposit or the collection does not exist
 
-
         """
         checks = self.checks(req, collection_name, deposit_id)
         if 'error' in checks:
@@ -739,7 +739,7 @@ class SWHPostDepositAPI(SWHBaseDeposit, metaclass=ABCMeta):
             return make_error_response_from_dict(req, error)
 
         data['packagings'] = ACCEPT_PACKAGINGS
-        iris = self._make_iris(collection_name, data['deposit_id'])
+        iris = self._make_iris(req, collection_name, data['deposit_id'])
         data.update(iris)
         response = render(req, 'deposit/deposit_receipt.xml',
                           context=data,
@@ -773,6 +773,7 @@ class SWHPutDepositAPI(SWHBaseDeposit, metaclass=ABCMeta):
             204 response when no error during routine occurred.
             400 if the deposit does not belong to the collection
             404 if the deposit or the collection does not exist
+
         """
         checks = self.checks(req, collection_name, deposit_id)
         if 'error' in checks:
diff --git a/swh/deposit/config.py b/swh/deposit/config.py
index 1408d2671d5d49128d572f39e2b8f2f97c34f359..67bd6f298a8081dd3a22a646501efd1f3cf7e613 100644
--- a/swh/deposit/config.py
+++ b/swh/deposit/config.py
@@ -14,7 +14,7 @@ EM_IRI = 'em_iri'
 CONT_FILE_IRI = 'cont_file_iri'
 SD_IRI = 'servicedocument'
 COL_IRI = 'upload'
-STATE_IRI = 'status'
+STATE_IRI = 'state_iri'
 PRIVATE_GET_RAW_CONTENT = 'private-download'
 PRIVATE_PUT_DEPOSIT = 'private-update'
 PRIVATE_GET_DEPOSIT_METADATA = 'private-read'
@@ -24,6 +24,8 @@ METADATA_KEY = 'metadata'
 
 AUTHORIZED_PLATFORMS = ['development', 'production', 'testing']
 
+DEPOSIT_STATUS_READY = 'ready'
+
 
 def setup_django_for(platform):
     """Setup function for command line tools (swh.deposit.create_user,
diff --git a/swh/deposit/injection/scheduler.py b/swh/deposit/injection/scheduler.py
index e1b5e788c24ec7e52254069007326204c08481ae..86783fced882ec9ac8b6e3977a15399b0218c09c 100644
--- a/swh/deposit/injection/scheduler.py
+++ b/swh/deposit/injection/scheduler.py
@@ -16,7 +16,7 @@ from celery import group
 
 from swh.core import utils
 from swh.core.config import SWHConfig
-from swh.deposit.config import setup_django_for
+from swh.deposit.config import setup_django_for, DEPOSIT_STATUS_READY
 
 
 class SWHScheduling(SWHConfig, metaclass=ABCMeta):
@@ -145,7 +145,7 @@ def get_deposit_ready():
 
     """
     from swh.deposit.models import Deposit
-    yield from Deposit.objects.filter(status='ready')
+    yield from Deposit.objects.filter(status=DEPOSIT_STATUS_READY)
 
 
 def prepare_task_arguments(server):
diff --git a/swh/deposit/models.py b/swh/deposit/models.py
index 2f9e26e543105250967f0b5f0a2d71e8c3e42cfd..c373700aa8da45b72012dbbae451405bb35a16a3 100644
--- a/swh/deposit/models.py
+++ b/swh/deposit/models.py
@@ -13,6 +13,8 @@ from django.contrib.auth.models import User, UserManager
 from django.db import models
 from django.utils.timezone import now
 
+from .config import DEPOSIT_STATUS_READY
+
 
 class Dbversion(models.Model):
     """Db version
@@ -37,7 +39,8 @@ class Dbversion(models.Model):
 DEPOSIT_STATUS = [
     ('partial', 'partial'),
     ('expired', 'expired'),
-    ('ready', 'ready'),
+    # ('ready-for-checks', 'ready-for-checks'),
+    (DEPOSIT_STATUS_READY, DEPOSIT_STATUS_READY),
     ('injecting', 'injecting'),
     ('success', 'success'),
     ('failure', 'failure'),
@@ -50,7 +53,10 @@ DEPOSIT_STATUS_DETAIL = {
                ' done in multiple requests',
     'expired': 'deposit has been there too long and is now '
                'deemed ready to be garbage collected',
-    'ready': 'deposit is fully received and ready for injection',
+    # 'ready-for-checks': 'Deposit is ready for supplementary checks '
+    #                     '(tarball ok, etc...)',
+    DEPOSIT_STATUS_READY: 'deposit is fully received and '
+                          'ready for injection',
     'injecting': "injection is ongoing on swh's side",
     'success': 'Injection is successful',
     'failure': 'Injection is a failure',
diff --git a/swh/deposit/settings/testing.py b/swh/deposit/settings/testing.py
index 9f6799c9bd8876633288ca710460bae34b822bb0..a8d3574c8aa50e53b03a1126957cea68570a07e4 100644
--- a/swh/deposit/settings/testing.py
+++ b/swh/deposit/settings/testing.py
@@ -4,10 +4,12 @@
 # See top-level LICENSE file for more information
 
 from .common import *  # noqa
+from .common import ALLOWED_HOSTS
 from .development import *  # noqa
 from .development import INSTALLED_APPS
 
 # django-nose setup
+ALLOWED_HOSTS += ['testserver']
 
 INSTALLED_APPS += ['django_nose']
 
diff --git a/swh/deposit/templates/deposit/deposit_receipt.xml b/swh/deposit/templates/deposit/deposit_receipt.xml
index 4eaa5cb900e4fc793d1271477010ba1febb9f27d..de934842c605cf1757a2d2c1d68c0eb7157ed3b6 100644
--- a/swh/deposit/templates/deposit/deposit_receipt.xml
+++ b/swh/deposit/templates/deposit/deposit_receipt.xml
@@ -4,6 +4,7 @@
     <deposit_id>{{ deposit_id }}</deposit_id>
     <deposit_date>{{ deposit_date }}</deposit_date>
     <deposit_archive>{{ archive }}</deposit_archive>
+    <deposit_state>{{ status }}</deposit_state>
 
     <!-- Edit-IRI -->
     <link rel="edit" href="{{ edit_se_iri }}" />
@@ -11,6 +12,8 @@
     <link rel="edit-media" href="{{ em_iri }}"/>
     <!-- SE-IRI -->
     <link rel="http://purl.org/net/sword/terms/add" href="{{ edit_se_iri }}" />
+    <!-- State-IRI -->
+    <link rel="state" href="{{ state_iri }}" />
 
     {% for packaging in packagings %}<sword:packaging>{{ packaging }}</sword:packaging>{% endfor %}
 </entry>
diff --git a/swh/deposit/templates/deposit/service_document.xml b/swh/deposit/templates/deposit/service_document.xml
index 42c1ee51f7b8fb8d9524d8d55e16e057bfbe9397..f66dae40613d0856739fd6d0d67f80e7f610d9ca 100644
--- a/swh/deposit/templates/deposit/service_document.xml
+++ b/swh/deposit/templates/deposit/service_document.xml
@@ -16,6 +16,7 @@
             <dcterms:abstract>Software Heritage Archive</dcterms:abstract>
             <sword:treatment>Collect, Preserve, Share</sword:treatment>
             <sword:mediation>false</sword:mediation>
+            <sword:metadataRelevantHeader>false</sword:metadataRelevantHeader>
             {% for accept_packaging in accept_packagings %}<sword:acceptPackaging>{{ accept_packaging }}</sword:acceptPackaging>{% endfor %}
             <sword:service>https://deposit.softwareheritage.org/1/{{ collection.name }}/</sword:service>
         </collection>{% endfor %}
diff --git a/swh/deposit/tests/api/test_deposit_atom.py b/swh/deposit/tests/api/test_deposit_atom.py
index 895c6765817ca0b81c97d807c622829a200767ab..ae96e151e97d26aebf209a347f2576fa4b1ba6b4 100644
--- a/swh/deposit/tests/api/test_deposit_atom.py
+++ b/swh/deposit/tests/api/test_deposit_atom.py
@@ -9,7 +9,7 @@ from nose.tools import istest
 from rest_framework import status
 from rest_framework.test import APITestCase
 
-from swh.deposit.config import COL_IRI
+from swh.deposit.config import COL_IRI, DEPOSIT_STATUS_READY
 from swh.deposit.models import Deposit, DepositRequest
 from swh.deposit.parsers import parse_xml
 
@@ -177,7 +177,7 @@ and other stuff</description>
         deposit = Deposit.objects.get(pk=deposit_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.external_id, external_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.client, self.user)
 
         # one associated request to a deposit
@@ -215,7 +215,7 @@ and other stuff</description>
         deposit = Deposit.objects.get(pk=deposit_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.external_id, external_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.client, self.user)
 
         # one associated request to a deposit
@@ -280,7 +280,7 @@ and other stuff</description>
         deposit = Deposit.objects.get(pk=deposit_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.external_id, external_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.client, self.user)
 
         self.assertEqual(len(Deposit.objects.all()), 1)
diff --git a/swh/deposit/tests/api/test_deposit_delete.py b/swh/deposit/tests/api/test_deposit_delete.py
index ea3caa90435bb58a728a2244d5a4ebe9f15a8326..13802050280dc2ef8f4a73ecc06827bc57b57e07 100644
--- a/swh/deposit/tests/api/test_deposit_delete.py
+++ b/swh/deposit/tests/api/test_deposit_delete.py
@@ -10,6 +10,8 @@ from rest_framework import status
 from rest_framework.test import APITestCase
 
 from swh.deposit.config import EDIT_SE_IRI, EM_IRI, ARCHIVE_KEY, METADATA_KEY
+from swh.deposit.config import DEPOSIT_STATUS_READY
+
 from swh.deposit.models import Deposit, DepositRequest
 from ..common import BasicTestCase, WithAuthTestCase, CommonCreationRoutine
 
@@ -65,7 +67,7 @@ class DepositDeleteTest(APITestCase, WithAuthTestCase, BasicTestCase,
         """Delete !partial status deposit should return a 400 response"""
         deposit_id = self.create_deposit_ready()
         deposit = Deposit.objects.get(pk=deposit_id)
-        assert deposit.status == 'ready'
+        assert deposit.status == DEPOSIT_STATUS_READY
 
         # when
         update_uri = reverse(EM_IRI, args=[self.collection.name, deposit_id])
diff --git a/swh/deposit/tests/api/test_deposit_multipart.py b/swh/deposit/tests/api/test_deposit_multipart.py
index 59f26f94bde585de84f3cb0bf9dcb989226d0f0d..aeb4a0538cc3fa533ff4b4875d21ece747af7c61 100644
--- a/swh/deposit/tests/api/test_deposit_multipart.py
+++ b/swh/deposit/tests/api/test_deposit_multipart.py
@@ -10,7 +10,7 @@ from nose.tools import istest
 from rest_framework import status
 from rest_framework.test import APITestCase
 
-from swh.deposit.config import COL_IRI
+from swh.deposit.config import COL_IRI, DEPOSIT_STATUS_READY
 from swh.deposit.models import Deposit, DepositRequest
 from swh.deposit.parsers import parse_xml
 from ..common import BasicTestCase, WithAuthTestCase
@@ -149,7 +149,7 @@ class DepositMultipartTestCase(APITestCase, WithAuthTestCase, BasicTestCase):
             '{http://www.w3.org/2005/Atom}deposit_id']
 
         deposit = Deposit.objects.get(pk=deposit_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.external_id, external_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.client, self.user)
@@ -247,7 +247,7 @@ class DepositMultipartTestCase(APITestCase, WithAuthTestCase, BasicTestCase):
 
         # deposit_id did not change
         deposit = Deposit.objects.get(pk=deposit_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.external_id, external_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.client, self.user)
diff --git a/swh/deposit/tests/api/test_deposit_read_archive.py b/swh/deposit/tests/api/test_deposit_read_archive.py
index 2cd56144833ac79b3e1096e47c696b1fe9ab481d..63d0ef18adc9c5483b4d08103f5927f884eeef49 100644
--- a/swh/deposit/tests/api/test_deposit_read_archive.py
+++ b/swh/deposit/tests/api/test_deposit_read_archive.py
@@ -102,7 +102,8 @@ class DepositReadArchivesTest(APITestCase, WithAuthTestCase, BasicTestCase,
         tarball.uncompress(self.archive_path, self.workdir)
         self.assertEquals(os.listdir(self.workdir), ['file1'])
         tarball.uncompress(self.archive_path2, self.workdir)
-        self.assertEquals(os.listdir(self.workdir), ['file1', 'file2'])
+        lst = set(os.listdir(self.workdir))
+        self.assertEquals(lst, {'file1', 'file2'})
 
         new_path = self.workdir + '.zip'
         tarball.compress(new_path, 'zip', self.workdir)
diff --git a/swh/deposit/tests/api/test_deposit_status.py b/swh/deposit/tests/api/test_deposit_status.py
index 48262625fe80317f5806124cd9e054647e48aedf..fd8112199f342d720b933ec37ecffddb7a470c7d 100644
--- a/swh/deposit/tests/api/test_deposit_status.py
+++ b/swh/deposit/tests/api/test_deposit_status.py
@@ -15,7 +15,7 @@ from swh.deposit.models import Deposit
 from swh.deposit.parsers import parse_xml
 
 from ..common import BasicTestCase, WithAuthTestCase
-from ...config import COL_IRI, STATE_IRI
+from ...config import COL_IRI, STATE_IRI, DEPOSIT_STATUS_READY
 
 
 class DepositStatusTestCase(APITestCase, WithAuthTestCase, BasicTestCase):
@@ -64,7 +64,7 @@ class DepositStatusTestCase(APITestCase, WithAuthTestCase, BasicTestCase):
         self.assertEqual(r['{http://www.w3.org/2005/Atom}deposit_id'],
                          deposit.id)
         self.assertEqual(r['{http://www.w3.org/2005/Atom}status'],
-                         'ready')
+                         DEPOSIT_STATUS_READY)
         self.assertEqual(r['{http://www.w3.org/2005/Atom}detail'],
                          'deposit is fully received and ready for injection')
 
diff --git a/swh/deposit/tests/api/test_deposit_update_status.py b/swh/deposit/tests/api/test_deposit_update_status.py
index 6980b8d626c4bc0b49bceb55085883b927459e81..2ef3f2c69e7eb92bf6f753a06672735a32ab7553 100644
--- a/swh/deposit/tests/api/test_deposit_update_status.py
+++ b/swh/deposit/tests/api/test_deposit_update_status.py
@@ -11,7 +11,7 @@ from rest_framework import status
 from rest_framework.test import APITestCase
 
 from swh.deposit.models import Deposit, DEPOSIT_STATUS_DETAIL
-from swh.deposit.config import PRIVATE_PUT_DEPOSIT
+from swh.deposit.config import PRIVATE_PUT_DEPOSIT, DEPOSIT_STATUS_READY
 from ..common import BasicTestCase
 
 
@@ -21,12 +21,12 @@ class UpdateDepositStatusTest(APITestCase, BasicTestCase):
     """
     def setUp(self):
         super().setUp()
-        deposit = Deposit(status='ready',
+        deposit = Deposit(status=DEPOSIT_STATUS_READY,
                           collection=self.collection,
                           client=self.user)
         deposit.save()
         self.deposit = Deposit.objects.get(pk=deposit.id)
-        assert self.deposit.status == 'ready'
+        assert self.deposit.status == DEPOSIT_STATUS_READY
 
     @istest
     def update_deposit_status(self):
diff --git a/swh/deposit/tests/api/test_service_document.py b/swh/deposit/tests/api/test_service_document.py
index dfb7f7448bcb04996306595739dd9f3fd90ab870..15a18391b4e40652a007b8b1f3664930ffc8b758 100644
--- a/swh/deposit/tests/api/test_service_document.py
+++ b/swh/deposit/tests/api/test_service_document.py
@@ -58,6 +58,7 @@ class ServiceDocumentCase(APITestCase, WithAuthTestCase, BasicTestCase):
             <dcterms:abstract>Software Heritage Archive</dcterms:abstract>
             <sword:treatment>Collect, Preserve, Share</sword:treatment>
             <sword:mediation>false</sword:mediation>
+            <sword:metadataRelevantHeader>false</sword:metadataRelevantHeader>
             <sword:acceptPackaging>http://purl.org/net/sword/package/SimpleZip</sword:acceptPackaging>
             <sword:service>https://deposit.softwareheritage.org/1/%s/</sword:service>
         </collection>
diff --git a/swh/deposit/tests/common.py b/swh/deposit/tests/common.py
index f1d6456af44ee1526f0cc252ed837e7b00ad0347..1baf620b7cdba284cea418a9eb3b5b16eb882390 100644
--- a/swh/deposit/tests/common.py
+++ b/swh/deposit/tests/common.py
@@ -144,10 +144,6 @@ class CommonCreationRoutine(TestCase):
             HTTP_IN_PROGRESS=status_partial,
             HTTP_CONTENT_DISPOSITION='attachment; filename=filename0.zip')
 
-        # then
-        if response.status_code != status.HTTP_201_CREATED:
-            print(response.status_code, response.content)
-
         # then
         assert response.status_code == status.HTTP_201_CREATED
         response_content = parse_xml(BytesIO(response.content))
@@ -164,12 +160,12 @@ class CommonCreationRoutine(TestCase):
             archive_path=archive_path)
 
         # Update the deposit to add another archive
-        # and update its status to 'ready'
+        # and update its status to DEPOSIT_STATUS_READY
         data, md5sum = self._init_data_from(
             archive_path2, b'some other data to pass as binary package')
 
         # Add a second archive to the deposit
-        # update its status to 'ready'
+        # update its status to DEPOSIT_STATUS_READY
         response = self.client.post(
             reverse(EM_IRI, args=[self.collection.name, deposit_id]),
             content_type='application/zip',
diff --git a/version.txt b/version.txt
index c4b2f804debab4a28e07635a23c9c90205e2ead1..f8ec149a20a2eb510d6d0142085e7eedbec10587 100644
--- a/version.txt
+++ b/version.txt
@@ -1 +1 @@
-v0.0.21-0-g4f4b192
\ No newline at end of file
+v0.0.22-0-g06d36f0
\ No newline at end of file
diff --git a/swh/deposit/tests/api/test_deposit_binary.py b/swh/deposit/tests/api/test_deposit_binary.py
index 1adf4f7e573b44e5d33c9c71770425a7024adb5f..1b45f451974581dd26c9a469ad38bf8f8a29e7fd 100644
--- a/swh/deposit/tests/api/test_deposit_binary.py
+++ b/swh/deposit/tests/api/test_deposit_binary.py
@@ -14,6 +14,7 @@ from rest_framework import status
 from rest_framework.test import APITestCase
 
 from swh.deposit.config import COL_IRI, EM_IRI
+from swh.deposit.config import DEPOSIT_STATUS_READY
 from swh.deposit.models import Deposit, DepositRequest
 from swh.deposit.parsers import parse_xml
 from ..common import BasicTestCase, WithAuthTestCase
@@ -211,7 +212,7 @@ and other stuff</description>
             '{http://www.w3.org/2005/Atom}deposit_id']
 
         deposit = Deposit.objects.get(pk=deposit_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.external_id, external_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.client, self.user)
@@ -233,7 +234,7 @@ and other stuff</description>
                               args=[self.collection.name, deposit.id])
 
         self.assertEqual(response._headers['location'],
-                         ('Location', edit_se_iri))
+                         ('Location', 'http://testserver' + edit_se_iri))
 
     @istest
     def post_deposit_binary_upload_only_supports_zip(self):
@@ -526,7 +527,7 @@ and other stuff</description>
             HTTP_CONTENT_DISPOSITION='attachment; filename=filename1')
 
         deposit = Deposit.objects.get(pk=deposit_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.external_id, external_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.client, self.user)
@@ -551,7 +552,7 @@ and other stuff</description>
 
     @istest
     def post_deposit_then_post_or_put_is_refused_when_status_ready(self):
         """Updating a deposit with status 'ready' should return a 400
 
         """
         url = reverse(COL_IRI, args=[self.collection.name])
@@ -583,7 +584,7 @@ and other stuff</description>
             '{http://www.w3.org/2005/Atom}deposit_id']
 
         deposit = Deposit.objects.get(pk=deposit_id)
-        self.assertEqual(deposit.status, 'ready')
+        self.assertEqual(deposit.status, DEPOSIT_STATUS_READY)
         self.assertEqual(deposit.external_id, external_id)
         self.assertEqual(deposit.collection, self.collection)
         self.assertEqual(deposit.client, self.user)
@@ -551,7 +552,7 @@ and other stuff</description>
     @istest
     def post_deposit_then_post_or_put_is_refused_when_status_ready(self):
-        """Updating a deposit with status 'ready' should return a 400
+        """Updating a deposit with status DEPOSIT_STATUS_READY should return a 400
 
         """